/*
    Copyright (C) 1995-1998 AROS - The Amiga Research OS
    $Id: freeargs.c,v 1.2 2007/04/15 22:21:05 piru Exp $

    Desc: Free arguments structure from ReadArgs()
    Lang: english
*/
#include <proto/exec.h>
#include <dos/rdargs.h>
#include "dos_intern.h"

/*****************************************************************************

    NAME */
#include <proto/dos.h>

	AROS_LH1(void, FreeArgs,

/*  SYNOPSIS */
	AROS_LHA(struct RDArgs *, args, D1),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 143, Dos)

/*  FUNCTION
	FreeArgs() will clean up after a call to ReadArgs(). If the
	RDArgs structure was allocated by the system in a call to 
	ReadArgs(), then it will be freed. If however, you allocated
	the RDArgs structure with AllocDosObject(), then you will
	have to free it yourself with FreeDosObject().

    INPUTS
	args		- The data used by ReadArgs(). May be NULL,
			  in which case, FreeArgs() does nothing.

    RESULT
	Some memory will have been returned to the system.

    NOTES

    EXAMPLE

    BUGS

    SEE ALSO
	ReadArgs()

    INTERNALS

    HISTORY
	29-10-95    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    DEBUG_RDARGS(dprintf("FreeArgs: args = $%lx\n", (ULONG) args));

    FAILFORTASKNP(return;)

    if(!args)
	return;

    /* ReadArgs() failed. Clean everything up. */
    if (args->RDA_DAList)
    {
	BOOL free_rda = ((struct DAList *)args->RDA_DAList)->FreeRDA;

	DEBUG_RDARGS(dprintf("FreeArgs: DAList = $%lx\n", args->RDA_DAList));

	dosFreeVec(((struct DAList *)args->RDA_DAList)->ArgBuf);
	dosFreeVec(((struct DAList *)args->RDA_DAList)->StrBuf);
	dosFreeVec(((struct DAList *)args->RDA_DAList)->MultVec);
	dosFreeVec((struct DAList *)args->RDA_DAList);

	if (free_rda)
	{
	    DEBUG_RDARGS(dprintf("FreeArgs: freeing RDArgs\n"));
	    dosFreeVec(args);
	}
        else
	    args->RDA_DAList = NULL; 
    }

    AROS_LIBFUNC_EXIT
} /* FreeArgs */
